# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.token_standard import TokenStandard  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestTokenStandard(unittest.TestCase):
    """TokenStandard unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTokenStandard(self):
        """Test TokenStandard"""
        # inst = TokenStandard()

if __name__ == '__main__':
    unittest.main()
