# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.notification_signature_public_key_data import NotificationSignaturePublicKeyData  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestNotificationSignaturePublicKeyData(unittest.TestCase):
    """NotificationSignaturePublicKeyData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test NotificationSignaturePublicKeyData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NotificationSignaturePublicKeyData`
        """
        model = circle.web3.configurations.models.notification_signature_public_key_data.NotificationSignaturePublicKeyData()  # noqa: E501
        if include_optional :
            return NotificationSignaturePublicKeyData(
                id = '09379bc1-4871-45ad-8b8b-8027795df70d', 
                algorithm = 'ECDSA_SHA_256', 
                public_key = 'QFkwewylAoZIzj0CBQYIKoZIzj0DAQcDQgAEEext6d7AimvYFDAKBwsUsGXrhqmRHNPYum7V/BwfvJLmJeSMe2V0b9eWKPuFxAEH8HCY/MSZdBI+q/E6IdPnSg==', 
                create_date = '2023-06-01T18:18:06.931526Z'
            )
        else :
            return NotificationSignaturePublicKeyData(
                id = '09379bc1-4871-45ad-8b8b-8027795df70d',
                algorithm = 'ECDSA_SHA_256',
                public_key = 'QFkwewylAoZIzj0CBQYIKoZIzj0DAQcDQgAEEext6d7AimvYFDAKBwsUsGXrhqmRHNPYum7V/BwfvJLmJeSMe2V0b9eWKPuFxAEH8HCY/MSZdBI+q/E6IdPnSg==',
                create_date = '2023-06-01T18:18:06.931526Z',
        )
        """

    def testNotificationSignaturePublicKeyData(self):
        """Test NotificationSignaturePublicKeyData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
