# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.faucet_request import FaucetRequest  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestFaucetRequest(unittest.TestCase):
    """FaucetRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test FaucetRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FaucetRequest`
        """
        model = circle.web3.configurations.models.faucet_request.FaucetRequest()  # noqa: E501
        if include_optional :
            return FaucetRequest(
                address = '', 
                blockchain = 'MATIC-AMOY', 
                native = True, 
                usdc = True, 
                eurc = True
            )
        else :
            return FaucetRequest(
                address = '',
                blockchain = 'MATIC-AMOY',
        )
        """

    def testFaucetRequest(self):
        """Test FaucetRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
