# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.entity_config import EntityConfig  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestEntityConfig(unittest.TestCase):
    """EntityConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EntityConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EntityConfig`
        """
        model = circle.web3.configurations.models.entity_config.EntityConfig()  # noqa: E501
        if include_optional :
            return EntityConfig(
                data = circle.web3.configurations.models.entity_config_data.EntityConfig_data(
                    app_id = '78fb905b-12c2-45aa-8fc4-c60261c9e9ee', )
            )
        else :
            return EntityConfig(
        )
        """

    def testEntityConfig(self):
        """Test EntityConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
