# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

import circle.web3.configurations
from circle.web3.configurations.api.webhook_subscriptions_api import WebhookSubscriptionsApi  # noqa: E501
from circle.web3.configurations.rest import ApiException


class TestWebhookSubscriptionsApi(unittest.TestCase):
    """WebhookSubscriptionsApi unit test stubs"""

    def setUp(self):
        self.api = circle.web3.configurations.api.webhook_subscriptions_api.WebhookSubscriptionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_subscription(self):
        """Test case for create_subscription

        Create a notification subscription  # noqa: E501
        """
        pass

    def test_delete_subscription(self):
        """Test case for delete_subscription

        Delete a notification subscription  # noqa: E501
        """
        pass

    def test_get_notification_signature(self):
        """Test case for get_notification_signature

        Get a notification signature public key  # noqa: E501
        """
        pass

    def test_get_subscription(self):
        """Test case for get_subscription

        Retrieve a notification subscription  # noqa: E501
        """
        pass

    def test_get_subscriptions(self):
        """Test case for get_subscriptions

        Get all notification subscriptions  # noqa: E501
        """
        pass

    def test_update_subscription(self):
        """Test case for update_subscription

        Update a notification subscription  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
