# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.not_found_response import NotFoundResponse  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestNotFoundResponse(unittest.TestCase):
    """NotFoundResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test NotFoundResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NotFoundResponse`
        """
        model = circle.web3.configurations.models.not_found_response.NotFoundResponse()  # noqa: E501
        if include_optional :
            return NotFoundResponse(
                code = 56, 
                message = ''
            )
        else :
            return NotFoundResponse(
                code = 56,
                message = '',
        )
        """

    def testNotFoundResponse(self):
        """Test NotFoundResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
