# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from circle.web3.configurations.models.blockchain import Blockchain
from circle.web3.configurations.models.token_standard import TokenStandard

class Token(BaseModel):
    """
    Token
    """
    id: StrictStr = Field(..., description="System-generated unique identifier of the resource.")
    name: Optional[StrictStr] = Field(None, description="Blockchain name of the specified token.")
    standard: Optional[TokenStandard] = None
    blockchain: Blockchain = Field(...)
    decimals: Optional[StrictInt] = Field(None, description="Number of decimal places shown in the token amount.")
    is_native: StrictBool = Field(..., alias="isNative", description="Defines if the token is a native token of the specified blockchain. If TRUE, the token is a native token.")
    symbol: Optional[StrictStr] = Field(None, description="Blockchain symbol of the specified token.")
    token_address: Optional[StrictStr] = Field(None, alias="tokenAddress", description="Blockchain address of the specified token.")
    update_date: datetime = Field(..., alias="updateDate", description="Date and time the resource was last updated, in ISO-8601 UTC format.")
    create_date: datetime = Field(..., alias="createDate", description="Date and time the resource was created, in ISO-8601 UTC format.")
    __properties = ["id", "name", "standard", "blockchain", "decimals", "isNative", "symbol", "tokenAddress", "updateDate", "createDate"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Token:
        """Create an instance of Token from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Token:
        """Create an instance of Token from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Token.parse_obj(obj)

        _obj = Token.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "standard": obj.get("standard"),
            "blockchain": obj.get("blockchain"),
            "decimals": obj.get("decimals"),
            "is_native": obj.get("isNative"),
            "symbol": obj.get("symbol"),
            "token_address": obj.get("tokenAddress"),
            "update_date": obj.get("updateDate"),
            "create_date": obj.get("createDate")
        })
        return _obj


