# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

import circle.web3.configurations
from circle.web3.configurations.api.faucet_api import FaucetApi  # noqa: E501
from circle.web3.configurations.rest import ApiException


class TestFaucetApi(unittest.TestCase):
    """FaucetApi unit test stubs"""

    def setUp(self):
        self.api = circle.web3.configurations.api.faucet_api.FaucetApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_request_testnet_tokens(self):
        """Test case for request_testnet_tokens

        Request testnet tokens  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
