# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

import circle.web3.configurations
from circle.web3.configurations.api.monitor_tokens_api import MonitorTokensApi  # noqa: E501
from circle.web3.configurations.rest import ApiException


class TestMonitorTokensApi(unittest.TestCase):
    """MonitorTokensApi unit test stubs"""

    def setUp(self):
        self.api = circle.web3.configurations.api.monitor_tokens_api.MonitorTokensApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_monitored_tokens(self):
        """Test case for create_monitored_tokens

        Set monitored tokens  # noqa: E501
        """
        pass

    def test_delete_monitored_tokens(self):
        """Test case for delete_monitored_tokens

        Delete monitored tokens  # noqa: E501
        """
        pass

    def test_list_monitored_tokens(self):
        """Test case for list_monitored_tokens

        Retrieve existing monitored tokens.  # noqa: E501
        """
        pass

    def test_update_monitored_tokens(self):
        """Test case for update_monitored_tokens

        Update monitored tokens  # noqa: E501
        """
        pass

    def test_update_monitored_tokens_scope(self):
        """Test case for update_monitored_tokens_scope

        Update monitored tokens scope  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
