# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.token import Token  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestToken(unittest.TestCase):
    """Token unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Token
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Token`
        """
        model = circle.web3.configurations.models.token.Token()  # noqa: E501
        if include_optional :
            return Token(
                id = 'c4d1da72-111e-4d52-bdbf-2e74a2d803d5', 
                name = '', 
                standard = 'ERC20', 
                blockchain = 'MATIC-AMOY', 
                decimals = 56, 
                is_native = True, 
                symbol = '', 
                token_address = '', 
                update_date = '2023-01-01T12:04:05Z', 
                create_date = '2023-01-01T12:04:05Z'
            )
        else :
            return Token(
                id = 'c4d1da72-111e-4d52-bdbf-2e74a2d803d5',
                blockchain = 'MATIC-AMOY',
                is_native = True,
                update_date = '2023-01-01T12:04:05Z',
                create_date = '2023-01-01T12:04:05Z',
        )
        """

    def testToken(self):
        """Test Token"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
