# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime

from pydantic import BaseModel, Field, StrictBool, StrictStr

class Subscription(BaseModel):
    """
    Contains information about a webhook notification subscription.
    """
    id: StrictStr = Field(..., description="System-generated unique identifier of the resource.")
    name: StrictStr = Field(..., description="Name of the webhook notification subscription.")
    endpoint: StrictStr = Field(..., description="URL of the endpoint subscribing to notifications. Must be enabled to receive notifications.")
    enabled: StrictBool = Field(..., description="Whether the subscription is enabled. `true` indicates the subscription is enabled.")
    create_date: datetime = Field(..., alias="createDate", description="Date and time the resource was created, in ISO-8601 UTC format.")
    update_date: datetime = Field(..., alias="updateDate", description="Date and time the resource was last updated, in ISO-8601 UTC format.")
    __properties = ["id", "name", "endpoint", "enabled", "createDate", "updateDate"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Subscription:
        """Create an instance of Subscription from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Subscription:
        """Create an instance of Subscription from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Subscription.parse_obj(obj)

        _obj = Subscription.parse_obj({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "endpoint": obj.get("endpoint"),
            "enabled": obj.get("enabled"),
            "create_date": obj.get("createDate"),
            "update_date": obj.get("updateDate")
        })
        return _obj


