# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

import circle.web3.configurations
from circle.web3.configurations.api.health_api import HealthApi  # noqa: E501
from circle.web3.configurations.rest import ApiException


class TestHealthApi(unittest.TestCase):
    """HealthApi unit test stubs"""

    def setUp(self):
        self.api = circle.web3.configurations.api.health_api.HealthApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_ping(self):
        """Test case for ping

        Ping  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
