# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

import circle.web3.configurations
from circle.web3.configurations.models.subscriptions import Subscriptions  # noqa: E501
from circle.web3.configurations.rest import ApiException

class TestSubscriptions(unittest.TestCase):
    """Subscriptions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Subscriptions
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Subscriptions`
        """
        model = circle.web3.configurations.models.subscriptions.Subscriptions()  # noqa: E501
        if include_optional :
            return Subscriptions(
                data = [
                    circle.web3.configurations.models.subscription.Subscription(
                        id = 'c4d1da72-111e-4d52-bdbf-2e74a2d803d5', 
                        name = 'Transactions Webhook', 
                        endpoint = 'https://example.org/handler/for/notifications', 
                        enabled = True, 
                        create_date = '2023-01-01T12:04:05Z', 
                        update_date = '2023-01-01T12:04:05Z', )
                    ]
            )
        else :
            return Subscriptions(
        )
        """

    def testSubscriptions(self):
        """Test Subscriptions"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
